#
# spec file for package libmng
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libmng2
Name:           libmng
Version:        2.0.3
Release:        3.7
Summary:        Library for Support of MNG and JNG Formats
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://www.libmng.com/
Source0:        https://downloads.sourceforge.net/project/%{name}/%{name}-devel/%{version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
Patch0:         libmng-1.0.9-dont-leak-zlib-streams.diff
BuildRequires:  cmake
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  man
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%{?suse_build_hwcaps_libs}

%description
This library can handle MNG and JNG formats that contain animated
pictures. These formats should replace the GIF format.

%package -n %{lname}
Summary:        Library for Support of MNG and JNG Formats
Group:          System/Libraries

%description -n %{lname}
This library can handle MNG and JNG formats that contain animated
pictures. These formats should replace the GIF format.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libjpeg-devel
Requires:       liblcms2-devel
Requires:       zlib-devel

%description devel
This library can handle MNG and JNG formats which contain animated
pictures. These formats should replace the GIF format.

This package contains the static library and the header files.

%prep
%autosetup -p0

%build
# This is not zlib licensed and unused, just as a caution, bnc#744320
rm -rf contrib

%cmake \
      -DCMAKE_SKIP_RPATH=ON \
      -DMNG_INSTALL_DOC_DIR=%{_docdir}/%{name} \
      -DBUILD_MAN=ON \
      -DBUILD_STATIC_LIBS=OFF ..
%cmake_build

%install
%cmake_install

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE
%doc README doc/doc.readme doc/libmng.txt
%{_libdir}/libmng.so.*

%files devel
%{_includedir}/*.h
%{_mandir}/*/*
%doc %{_docdir}/libmng/
%{_libdir}/pkgconfig/libmng.pc
%{_libdir}/libmng.so
%{_datadir}/mng-2.0/

%changelog
* Wed Mar  8 2023 Martin Pluskal <mpluskal@suse.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
- Modernise spec file
* Wed May  4 2022 Marcus Meissner <meissner@suse.com>
- urls changed to https
* Mon Apr 27 2015 mpluskal@suse.com
- Update to 2.0.3
  * More changes to libmng_types.h.
- Cleanup spec file with spec-cleaner
- Remove old obsolete/provide
- Use %%cmake macro when building
- Remove no longer needed fix-header-include.patch
* Tue Jun 17 2014 hrvoje.senjan@gmail.com
- Fix requires of devel subpackage: with switch to lcms2, the devel
  package wasn't adjusted
* Tue May 20 2014 hrvoje.senjan@gmail.com
- Added fix-header-include.patch; make libmng_types header usable
  to outside packages/libraries
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Update to 2.0.2
  * Added support for lcms2.
  * Added support for libjpeg version 9.
- Bump %%lname to libmng2, per upstream change (also adjusted baselibs)
- Switch to CMake buildsystem: added cmake BuildRequires
- Added pkg-config and man BuildRequires
- BuildRequire liblcms2-devel instead of liblcms-devel
- Drop libmng-no-jpeg.diff and libmng.diff, not needed with good, CMake
  buildsystem
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb  1 2012 idonmez@suse.com
- Remove contrib directory during build, its unused and might
  confuse licensing, bnc#744320
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Do shlib policy packaging
* Sat Feb 13 2010 adrian@suse.de
- remove obsolete and not anymmore existing libjpeg in buildrequies
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Tue Jun  9 2009 crrodriguez@suse.de
- remove libmng.a
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jul 19 2007 ltinkl@suse.cz
- update to 1.0.10
  * fixed some compiler-warnings
  * fixed display routines called twice for FULL_MNG support in mozlibmngconf.h
  * standard windows dll upgraded to zlib 1.2.3
  * fixed problem with CLON object during readdisplay() (thanks Winfried!)
  * added typecast to appease the compiler (G R-P)
  * added more SKIPCHUNK conditionals (G R-P)
  * added MORE MNG_NO_1_2_4BIT_SUPPORT (G R-P)
  * added provisional support for anIM(mpNG) proposal
  * added provisional support for ANG proposal
- fix patches
- provide %%post sections
* Thu Mar 29 2007 meissner@suse.de
- buildrequires zlib-devel
* Tue Oct 24 2006 ltinkl@suse.cz
- fix runtime header require (still #208994)
* Mon Oct 23 2006 ltinkl@suse.cz
- fix build (#208994)
* Fri Sep 29 2006 dmueller@suse.de
- fix memory leak
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb  4 2005 adrian@suse.de
- fix missing symbols in libmng-mini
* Tue Feb  1 2005 adrian@suse.de
- update to version 1.0.9
- disable also liblcms in libmng-mini.a
* Thu Sep 23 2004 mls@suse.de
- really disable jpeg in mini libmng.a
* Mon Aug  9 2004 adrian@suse.de
- update to version 1.0.8
* Sun Dec 21 2003 adrian@suse.de
- update to version 1.0.6
* Thu Mar  6 2003 adrian@suse.de
- update to 1.0.5 final
  * libjpeg suspension not always honored correctly
* Mon Jan 20 2003 adrian@suse.de
- update to 1.0.5-rc3
  * Minor bug-fixes
* Fri Dec 20 2002 adrian@suse.de
- update to 1.0.5-rc2
  * lots of new features
* Wed Dec 18 2002 adrian@suse.de
- require liblcms-devel
* Tue Aug  6 2002 adrian@suse.de
- run_ldconfig
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jun 28 2002 ro@suse.de
- re-run auto* tools to get library linked to libjpeg and liblcms
  correctly on lib64 platforms
* Mon Jun 24 2002 adrian@suse.de
- update to version 1.0.4
  * hugh bugfix release, /usr/share/doc/packages/libmng/Changes
    describes changes
  * remove obsolete patches
* Fri Jun 21 2002 adrian@suse.de
- fix doc and man page locations (#15978)
* Fri May 31 2002 adrian@suse.de
- fix build for ppc64
* Fri Mar  8 2002 sf@suse.de
- corrected configure to to build with lcms
* Wed Feb  6 2002 coolo@suse.de
- fix %%_libdir
* Mon Jan  7 2002 adrian@suse.de
- use %%{_libdir}
* Tue Oct 16 2001 adrian@suse.de
- update to 1.0.3
- clean compatibility lib
* Fri Aug 24 2001 adrian@suse.de
- fix to compile without jpeg support for libmng-mini.a
* Thu Aug 23 2001 adrian@suse.de
- build extra small libmng-mini.a
  needed for inst-sys application
* Mon Jul  9 2001 adrian@suse.de
- update to version 1.0.2
* Thu Apr  5 2001 adrian@suse.de
- add the same lib with so name libmng.so.0 for compatibility
* Fri Feb  9 2001 adrian@suse.de
- update to version 1.0.0
  fix spec file for non i386 (thanks Bernd)
* Wed Nov 29 2000 adrian@suse.de
- update to 0.9.3
  fixing liblcms support
  dropped jpeg support for old (<6.4) distris
* Fri Nov 17 2000 adrian@suse.de
- split package into libmng and libmng-devel
* Wed Oct  4 2000 adrian@suse.de
- initial package; version 0.9.2
